@@ -313,6 +313,15 @@ def compile_quarterly_composite_filepath(archive_root, year, sitecode, quarter):
     basename = basename.format(startdate=startdate, enddate=enddate, sitecode=sitecode)
     return archive_root.joinpath(str(year), countrycode, sitecode, "MTC", "OPT", basename)
 
+def locate_training_polygons(training_polygon_parent_path, year, bioregion, training_epsg):
+    year = int(year)
+    training_polygons_basename = "trainingdata_{bioregion}_{year}_{epsg}.gpkg".format(
+        bioregion=bioregion, year=year, epsg=training_epsg)
+    log.debug("looking for training polygon with name: {}".format(training_polygons_basename))
+    training_polygons_filepath = Path(training_polygon_parent_path).joinpath(bioregion, str(year), "training_data", training_polygons_basename)
+    log.debug("looking for training polygon in: {}".format(training_polygons_filepath))
+    return training_polygons_filepath
+
 #################################################################################################
 #################################################################################################
 def find_file_in_archives(relative_path, archive_roots, error_on_missing=True):
